@@ -10,6 +10,7 @@ pub struct GitStatusConfig<'a> {
     pub stashed: &'a str,
     pub ahead: &'a str,
     pub behind: &'a str,
+    pub up_to_date: &'a str,
     pub diverged: &'a str,
     pub conflicted: &'a str,
     pub deleted: &'a str,
@@ -28,6 +29,7 @@ impl<'a> Default for GitStatusConfig<'a> {
             stashed: "\\$",
             ahead: "⇡",
             behind: "⇣",
+            up_to_date: "",
             diverged: "⇕",
             conflicted: "=",
             deleted: "✘",
