@@ -18,6 +18,7 @@ mod erlang;
 mod gcloud;
 mod git_branch;
 mod git_commit;
+mod git_metrics;
 mod git_state;
 mod git_status;
 mod golang;
@@ -64,6 +65,9 @@ mod zig;
 #[cfg(feature = "battery")]
 mod battery;
 
+#[cfg(feature = "battery")]
+pub use self::battery::{BatteryInfoProvider, BatteryInfoProviderImpl};
+
 use crate::config::RootModuleConfig;
 use crate::context::{Context, Shell};
 use crate::module::Module;
@@ -71,7 +75,6 @@ use std::time::Instant;
 
 pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
     let start: Instant = Instant::now();
-
     let mut m: Option<Module> = {
         match module {
             // Keep these ordered alphabetically.
@@ -95,6 +98,7 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
             "gcloud" => gcloud::module(context),
             "git_branch" => git_branch::module(context),
             "git_commit" => git_commit::module(context),
+            "git_metrics" => git_metrics::module(context),
             "git_state" => git_state::module(context),
             "git_status" => git_status::module(context),
             "golang" => golang::module(context),
@@ -177,6 +181,7 @@ pub fn description(module: &str) -> &'static str {
         "gcloud" => "The current GCP client configuration",
         "git_branch" => "The active branch of the repo in your current directory",
         "git_commit" => "The active commit (and tag if any) of the repo in your current directory",
+        "git_metrics" => "The currently added/deleted lines in your repo",
         "git_state" => "The current git operation, and it's progress",
         "git_status" => "Symbol representing the state of the repo",
         "golang" => "The currently installed version of Golang",
